Changelog
=========


(unreleased)
------------

Fix
~~~
- Python 3.8 compatable. [Huajian Mao]
- No openai issue. [Huajian Mao]

Other
~~~~~
- Chore: processing tool call exception. [Huajian Mao]
- Chore: load Files store path from .env. [Huajian Mao]
- Feat: add support of qwen models. [Huajian Mao]
- Chore: make fmt. [Huajian Mao]
- Chore: debug for different models. [Huajian Mao]
- Feat: set system prompt if not exists in messages. [Huajian Mao]
- Chore: add ChunkUtils. [Huajian Mao]
- Chore: minor revision on gpt from_yaml. [Huajian Mao]
- Feat: add support of tools returing bytes. [Huajian Mao]
- Feat: add chat for gpt. [Huajian Mao]
- Chore: rename trigger to name. [Huajian Mao]
- Feat: support multiple type of tool call result. [Huajian Mao]


0.0.3 (2024-08-19)
------------------

Fix
~~~
- Lint issues. [Huajian Mao]
- Tool call exception. [Huajian Mao]

Other
~~~~~
- Release: version 0.0.3 🚀 [Huajian Mao]
- Release: version 0.0.3 🚀 [Huajian Mao]
- Chore: fix fmt issue. [Huajian Mao]
- Refact: add github workflows. [Huajian Mao]
- Release: v0.0.2. [Huajian Mao]
- Chore: add temp.py to .gitignore. [Huajian Mao]
- Feat: add file storage. [Huajian Mao]
- Feat: register tools. [Huajian Mao]
- Chore: revise on_fc param. [Huajian Mao]
- Chore: add test for gpt. [Huajian Mao]
- Feat: add gpt class. [Huajian Mao]
- Feat: add llm chat. [Huajian Mao]
- Init: add project sketch code. [Huajian Mao]


